pub enum Value {
Null,
Bool(bool),
Number(Number),
String(String),
Array(Vec<Value>),
Object(HashMap<String, Value, FxBuildHasher>),
}Expand description
Represents any valid JSON value.
Variants
Null
JSON null value.
Bool(bool)
JSON boolean value (true or false).
Number(Number)
JSON numeric value (integer or floating point).
String(String)
JSON string value.
Array(Vec<Value>)
JSON array containing a sequence of values.
Object(HashMap<String, Value, FxBuildHasher>)
JSON object containing key-value pairs.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
If the value is a boolean, returns the associated bool. Returns None otherwise.
Sourcepub fn as_i64(&self) -> Option<i64>
pub fn as_i64(&self) -> Option<i64>
If the value is a number, tries to return it as an i64. Returns None if the value is not a number or cannot be represented as i64.
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
If the value is a number, returns it as an f64. Returns None if the value is not a number.
Sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
If the value is a string, returns the associated str. Returns None otherwise.