pub type Lexer<'a> = LogosLexer<'a>;Expand description
Type alias for backward compatibility with the original Lexer API.
Aliased Type
pub struct Lexer<'a> { /* private fields */ }pub type Lexer<'a> = LogosLexer<'a>;Type alias for backward compatibility with the original Lexer API.
pub struct Lexer<'a> { /* private fields */ }